@@ -1,18 +1,16 @@
 #!/usr/bin/env python
-import os
-import sys
 import argparse
 import logging
 import logging.config
+import os
+import sys
 
-from rq import Queue, Worker
+from rq import Queue
 from rq.logutils import setup_loghandlers
 from redis.exceptions import ConnectionError
 from rq.contrib.legacy import cleanup_ghosts
-from rq.scripts import add_standard_arguments
-from rq.scripts import setup_redis
-from rq.scripts import read_config_file
-from rq.scripts import setup_default_arguments
+from rq.scripts import add_standard_arguments, read_config_file, setup_default_arguments, setup_redis
+from rq.utils import import_attribute
 
 logger = logging.getLogger(__name__)
 
@@ -21,12 +19,15 @@ def parse_args():
     parser = argparse.ArgumentParser(description='Starts an RQ worker.')
     add_standard_arguments(parser)
 
-    parser.add_argument('--burst', '-b', action='store_true', default=False, help='Run in burst mode (quit after all work is done)')
+    parser.add_argument('--burst', '-b', action='store_true', default=False, help='Run in burst mode (quit after all work is done)')  # noqa
     parser.add_argument('--name', '-n', default=None, help='Specify a different name')
+    parser.add_argument('--worker-class', '-w', action='store', default='rq.Worker', help='RQ Worker class to use')
     parser.add_argument('--path', '-P', default='.', help='Specify the import path.')
+    parser.add_argument('--results-ttl', default=None, help='Default results timeout to be used')
+    parser.add_argument('--worker-ttl', default=None, help='Default worker timeout to be used')
     parser.add_argument('--verbose', '-v', action='store_true', default=False, help='Show more output')
     parser.add_argument('--quiet', '-q', action='store_true', default=False, help='Show less output')
-    parser.add_argument('--sentry-dsn', action='store', default=None, metavar='URL', help='Report exceptions to this Sentry DSN')
+    parser.add_argument('--sentry-dsn', action='store', default=None, metavar='URL', help='Report exceptions to this Sentry DSN')  # noqa
     parser.add_argument('--pid', action='store', default=None,
                         help='Write the process ID number to a file at the specified path')
     parser.add_argument('queues', nargs='*', help='The queues to listen on (default: \'default\')')
@@ -75,10 +76,14 @@ def main():
     setup_redis(args)
 
     cleanup_ghosts()
+    worker_class = import_attribute(args.worker_class)
 
     try:
         queues = list(map(Queue, args.queues))
-        w = Worker(queues, name=args.name)
+        w = worker_class(queues,
+                         name=args.name,
+                         default_worker_ttl=args.worker_ttl,
+                         default_result_ttl=args.results_ttl)
 
         # Should we configure Sentry?
         if args.sentry_dsn:
